Reader

Struct Reader 

pub struct Reader<'a, Input: Read> { /* private fields */ }
Reader implements buffering for an std::io::Read object.

Consider using native Rust std::io::BufReader.

Implementations

Source

impl<'a, Input: Read> Reader<'a, Input>

pub fn new(r: &'a mut Input) -> Self

new creates a reader with the default size buffer

pub fn new_size(r: &'a mut Input, size: usize) -> Self

new_size returns a new Reader whose buffer has at least the specified size.

pub fn size(&mut self) -> usize

size returns the size of the underlying buffer in bytes.

pub fn reset(&mut self, r: &'a mut Input)

reset discards any buffered data, resets all state, and switches the buffered reader to read from r.

pub fn peek(&mut self, n: usize) -> (&[u8], Option<Box<dyn Error>>)

peek returns the next n bytes without advancing the reader. The bytes stop being valid at the next read call. If peek returns fewer than n bytes, it also returns an error explaining why the read is short. The error is ERR_BUFFER_FULL if n is larger than b’s buffer size.

Calling peek prevents a UnreadByte or UnreadRune call from succeeding until the next read operation.

pub fn buffered(&mut self) -> usize

buffered returns the number of bytes that can be read from the current buffer.