CBCEncrypter

Struct CBCEncrypter 

pub struct CBCEncrypter<'a, B: Block> { /* private fields */ }
CBCEncrypter implements encryption in cipher block chaining mode, using the given Block.

Implementations

Source

impl<'a, B: Block> CBCEncrypter<'a, B>

pub fn new(b: &'a B, iv: &[u8]) -> Self

new returns a BlockMode which encrypts in cipher block chaining mode, using the given Block. The length of iv must be the same as the Block’s block size.

Examples found in repository?
examples/aes.rs (line 70)
59fn aes_cbc(key: &[u8], plaintext: &[u8]) {
60    let block = aes::Cipher::new(key).unwrap();
61    assert!(
62        plaintext.len() % aes::BLOCK_SIZE == 0,
63        "Plaintext length must be a multiple of the block size"
64    );
65
66    // Using the initialization vector of all zeroes for demo purposes.
67    // In practice the IV should be unique for each encryption operation and upredictable,
68    // for example, generated using a secure random generator.
69    let iv = vec![0; aes::BLOCK_SIZE];
70    let mut mode = cipher::CBCEncrypter::new(&block, &iv);
71
72    let mut encrypted = vec![0; plaintext.len()];
73    mode.crypt_blocks(&mut encrypted, plaintext);
74
75    // let mut mode = cipher::CBCDecrypter::new(&block, &iv);
76    // let mut decrypted = vec![0; plaintext.len()];
77    // mode.crypt_blocks(&mut decrypted, &encrypted);
78
79    // println!("plaintext:      {}", String::from_utf8_lossy(plaintext));
80    println!("CBC encrypted:  {}", hex::encode_to_string(&encrypted));
81    // println!("decrypted:      {}", String::from_utf8_lossy(&decrypted));
82    // println!();
83}
pub fn set_iv(&mut self, iv: &[u8])