Alpha16

Struct Alpha16 

pub struct Alpha16 {
    pub pix: Vec<u8>,
    pub stride: usize,
    /* private fields */
}
Alpha16 is an in-memory image whose At method returns color::Alpha16 values.

Fields

pix: Vec<u8>stride: usize

stride is the pix stride (in bytes) between vertically adjacent pixels.

Implementations

Source

impl Alpha16

pub fn new(r: &Rectangle) -> Self

new returns a new Alpha16 image with the given bounds.

pub fn pix_offset(&self, x: isize, y: isize) -> usize

pix_offset returns the index of the first element of pix that corresponds to the pixel at (x, y).