pub struct TempDir {
pub path: PathBuf,
/* private fields */
}Expand description
TempDir contains information about a created temporary directory and will remove the directory recursively after the object goes out of scope. This is a convenience structure over mkdir_temp results.
Fields
path: PathBufImplementations
Sourceimpl TempDir
impl TempDir
Sourcepub fn new(pattern: &str) -> Result<Self>
pub fn new(pattern: &str) -> Result<Self>
new creates a new temporary directory in the default directory for temporary files. The new directory’s name is generated by adding a random string to the end of pattern. If pattern includes a “”, the random string replaces the last “” instead. The temporary directory will be removed when the object goes out of scope.
Sourcepub fn new_in_dir(dir: &Path, pattern: &str) -> Result<Self>
pub fn new_in_dir(dir: &Path, pattern: &str) -> Result<Self>
new_in_dir is the same as new, except that the directory dir is used instead
of the system directory for temporary files.