TempFile

Struct TempFile 

pub struct TempFile {
    pub f: File,
    pub path: PathBuf,
    /* private fields */
}
TempFile contains information about a created temporary file and will remove the temporary file after the object goes out of scope. This is a convenience structure over create_temp results.

Fields

f: Filepath: PathBuf

Implementations

Source

impl TempFile

pub fn new(pattern: &str) -> Result<Self>

new creates a new temporary file in the default directory for temporary files. The new file’s name is generated by adding a random string to the end of pattern. If pattern includes a “”, the random string replaces the last “” instead. The temporary file will be removed when the object goes out of scope.

Examples found in repository?
examples/tempfile.rs (line 8)
7fn main() {
8    let tf = TempFile::new("ggstd-*.txt").unwrap();
9    println!("{}", tf.path.to_string_lossy());
10
11    let td = TempDir::new("ggstd-").unwrap();
12    println!("{}", td.path.to_string_lossy());
13
14    let tf = TempFile::new_in_dir(&td.path, "ggstd-*.txt").unwrap();
15    println!("{}", tf.path.to_string_lossy());
16}
pub fn new_in_dir(dir: &Path, pattern: &str) -> Result<Self>

new_in_dir is the same as new, except that the directory dir is used instead of the system directory for temporary files.

Examples found in repository?
examples/tempfile.rs (line 14)
7fn main() {
8    let tf = TempFile::new("ggstd-*.txt").unwrap();
9    println!("{}", tf.path.to_string_lossy());
10
11    let td = TempDir::new("ggstd-").unwrap();
12    println!("{}", td.path.to_string_lossy());
13
14    let tf = TempFile::new_in_dir(&td.path, "ggstd-*.txt").unwrap();
15    println!("{}", tf.path.to_string_lossy());
16}
pub fn remove(&mut self) -> Result<()>

remove removes the file