Time

Struct Time 

pub struct Time { /* private fields */ }
A Time represents an instant in time with nanosecond precision.

Implementations

Source

impl Time

pub fn from_systime(sys_time: &SystemTime) -> Self

from_systime creates Time structure from std::time::SystemTime

Examples found in repository?
examples/time.rs (line 13)
8fn main() {
9    println!("epoch start: {}", format_time(&time::unix(0, 0)));
10    println!("now:         {}", format_time(&time::now()));
11    println!(
12        "now systime: {}",
13        format_time(&Time::from_systime(&SystemTime::now()))
14    );
15}
pub fn from_unix(sec: i64, nsec: i64) -> Self

unix returns the local Time corresponding to the given Unix time, sec seconds and nsec nanoseconds since January 1, 1970 UTC. It is valid to pass nsec outside the range [0, 999999999]. Not all sec values have a corresponding time value. One such value is 1<<63-1 (the largest i64 value).

This is the same as unix.

Source

impl Time

pub fn date(&self) -> YMD

pub fn year(&self) -> isize

year returns the year in which t occurs.

Examples found in repository?
examples/time.rs (line 20)
17fn format_time(t: &Time) -> String {
18    format!(
19        "{:04}-{:02}-{:02} {:02}:{:02}:{:02}",
20        t.year(),
21        t.month(),
22        t.day(),
23        t.hour(),
24        t.minute(),
25        t.second()
26    )
27}
pub fn month(&self) -> usize

month returns the month of the year specified by self.

Examples found in repository?
examples/time.rs (line 21)
17fn format_time(t: &Time) -> String {
18    format!(
19        "{:04}-{:02}-{:02} {:02}:{:02}:{:02}",
20        t.year(),
21        t.month(),
22        t.day(),
23        t.hour(),
24        t.minute(),
25        t.second()
26    )
27}
pub fn day(&self) -> usize

Examples found in repository?
examples/time.rs (line 22)
17fn format_time(t: &Time) -> String {
18    format!(
19        "{:04}-{:02}-{:02} {:02}:{:02}:{:02}",
20        t.year(),
21        t.month(),
22        t.day(),
23        t.hour(),
24        t.minute(),
25        t.second()
26    )
27}
pub fn weekday(&self) -> usize

Source

impl Time

pub fn clock(&self) -> HMS

clock returns the hour, minute, and second within the day specified by self.

pub fn hour(&self) -> u8

hour returns the hour within the day specified by t, in the range [0, 23].

Examples found in repository?
examples/time.rs (line 23)
17fn format_time(t: &Time) -> String {
18    format!(
19        "{:04}-{:02}-{:02} {:02}:{:02}:{:02}",
20        t.year(),
21        t.month(),
22        t.day(),
23        t.hour(),
24        t.minute(),
25        t.second()
26    )
27}
pub fn minute(&self) -> u8

minute returns the minute offset within the hour specified by t, in the range [0, 59].

Examples found in repository?
examples/time.rs (line 24)
17fn format_time(t: &Time) -> String {
18    format!(
19        "{:04}-{:02}-{:02} {:02}:{:02}:{:02}",
20        t.year(),
21        t.month(),
22        t.day(),
23        t.hour(),
24        t.minute(),
25        t.second()
26    )
27}
pub fn second(&self) -> u8

second returns the second offset within the minute specified by t, in the range [0, 59].

Examples found in repository?
examples/time.rs (line 25)
17fn format_time(t: &Time) -> String {
18    format!(
19        "{:04}-{:02}-{:02} {:02}:{:02}:{:02}",
20        t.year(),
21        t.month(),
22        t.day(),
23        t.hour(),
24        t.minute(),
25        t.second()
26    )
27}
pub fn nanosecond(&self) -> usize

nanosecond returns the nanosecond offset within the second specified by t, in the range [0, 999999999].

pub fn year_day(&self) -> usize

year_day returns the day of the year specified by t, in the range [1,365] for non-leap years, and [1,366] in leap years.

Source

impl Time

pub fn unix(&self) -> i64

pub fn unix_nano(&self) -> i64

unix_nano returns t as a Unix time, the number of nanoseconds elapsed since January 1, 1970 UTC. The result is undefined if the Unix time in nanoseconds cannot be represented by an i64 (a date before the year 1678 or after 2262). Note that this means the result of calling unix_nano on the zero Time is undefined. The result does not depend on the location associated with t.