pub struct TempFile {
pub f: File,
pub path: PathBuf,
/* private fields */
}Expand description
TempFile contains information about a created temporary file and will remove the temporary file after the object goes out of scope. This is a convenience structure over create_temp results.
Fields
f: Filepath: PathBufImplementations
Sourceimpl TempFile
impl TempFile
Sourcepub fn new(pattern: &str) -> Result<Self>
pub fn new(pattern: &str) -> Result<Self>
new creates a new temporary file in the default directory for temporary files. The new file’s name is generated by adding a random string to the end of pattern. If pattern includes a “”, the random string replaces the last “” instead. The temporary file will be removed when the object goes out of scope.
Sourcepub fn new_in_dir(dir: &Path, pattern: &str) -> Result<Self>
pub fn new_in_dir(dir: &Path, pattern: &str) -> Result<Self>
new_in_dir is the same as new, except that the directory dir is used instead
of the system directory for temporary files.