quote_bytes_string is similar to Quote, but takes slice of bytes
instead of a string. This is useful in cases when replacing Go Quote
function when the Go string contains arbitrary data (in Go strings
can contain arbitrary data, in Rust they cannot).